# quepasa
API for RAG retrieval, managing documents, files, and related operations including Telegram integration.

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 0.0.1
- Package version: 1.0.0
- Generator version: 7.8.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 3.7+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import quepasa
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import quepasa
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import quepasa
from quepasa.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://api.quepasa.ai/api/v1
# See configuration.py for a list of all supported configuration parameters.
configuration = quepasa.Configuration(
    host = "https://api.quepasa.ai/api/v1"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure Bearer authorization (Opaque): bearerAuth
configuration = quepasa.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)


# Enter a context with an instance of the API client
with quepasa.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = quepasa.DefaultApi(api_client)
    id = 'id_example' # str | 

    try:
        # Get batch status
        api_response = api_instance.get_batch_status(id)
        print("The response of DefaultApi->get_batch_status:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling DefaultApi->get_batch_status: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://api.quepasa.ai/api/v1*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*DefaultApi* | [**get_batch_status**](docs/DefaultApi.md#get_batch_status) | **GET** /upload/data/batches/{id} | Get batch status
*DefaultApi* | [**get_document**](docs/DefaultApi.md#get_document) | **GET** /upload/data/documents/{domain}/{id} | Get document details
*DefaultApi* | [**list_documents**](docs/DefaultApi.md#list_documents) | **GET** /upload/data/documents/{domain} | List documents
*DefaultApi* | [**remove_document**](docs/DefaultApi.md#remove_document) | **DELETE** /upload/data/documents/{domain}/{id} | Remove document
*DefaultApi* | [**replace_documents**](docs/DefaultApi.md#replace_documents) | **PUT** /upload/data/documents/{domain} | Replace documents
*DefaultApi* | [**reset_documents**](docs/DefaultApi.md#reset_documents) | **DELETE** /upload/data/documents/{domain} | Reset documents
*DefaultApi* | [**retrieve_answer**](docs/DefaultApi.md#retrieve_answer) | **POST** /retrieve/answer | Retrieve answers or search data
*DefaultApi* | [**retrieve_chunks**](docs/DefaultApi.md#retrieve_chunks) | **POST** /retrieve/chunks | Retrieve answers or search data
*DefaultApi* | [**setup_telegram**](docs/DefaultApi.md#setup_telegram) | **PATCH** /upload/data/telegram | Setup Telegram integration
*DefaultApi* | [**upsert_documents**](docs/DefaultApi.md#upsert_documents) | **POST** /upload/data/documents/{domain} | Upsert documents
*DefaultApi* | [**upsert_files**](docs/DefaultApi.md#upsert_files) | **POST** /upload/data/files/{domain} | Upsert files


## Documentation For Models

 - [AnswerDetail](docs/AnswerDetail.md)
 - [AnswerDetailData](docs/AnswerDetailData.md)
 - [AnswerDetailDataLabeledLinksValue](docs/AnswerDetailDataLabeledLinksValue.md)
 - [AnswerDetailDataLinksValue](docs/AnswerDetailDataLinksValue.md)
 - [BatchStatus](docs/BatchStatus.md)
 - [BatchStatusData](docs/BatchStatusData.md)
 - [ChunksDetail](docs/ChunksDetail.md)
 - [ChunksDetailDataInner](docs/ChunksDetailDataInner.md)
 - [CreatedBatchStatus](docs/CreatedBatchStatus.md)
 - [CreatedBatchStatusData](docs/CreatedBatchStatusData.md)
 - [Document](docs/Document.md)
 - [DocumentDetail](docs/DocumentDetail.md)
 - [DocumentDetailData](docs/DocumentDetailData.md)
 - [DocumentDetailDataPagesInner](docs/DocumentDetailDataPagesInner.md)
 - [DocumentNotFound](docs/DocumentNotFound.md)
 - [DocumentPagesInner](docs/DocumentPagesInner.md)
 - [OperationFailedStatus](docs/OperationFailedStatus.md)
 - [RetrieveAnswerRequest](docs/RetrieveAnswerRequest.md)
 - [RetrieveAnswerRequestUserInfo](docs/RetrieveAnswerRequestUserInfo.md)
 - [SetupTelegramRequest](docs/SetupTelegramRequest.md)
 - [SetupTelegramRequestCommands](docs/SetupTelegramRequestCommands.md)
 - [SetupTelegramRequestCommandsAsk](docs/SetupTelegramRequestCommandsAsk.md)
 - [SetupTelegramRequestCommandsStart](docs/SetupTelegramRequestCommandsStart.md)
 - [TelegramStatus](docs/TelegramStatus.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="bearerAuth"></a>
### bearerAuth

- **Type**: Bearer authentication (Opaque)


## Author




